
# Slot: number_of_enabled_by_terms

The number of molecular entities or sets of entities in a model.

URI: [gocam:queryIndex__number_of_enabled_by_terms](https://w3id.org/gocam/queryIndex__number_of_enabled_by_terms)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [QueryIndex](QueryIndex.md)
